@@ -1,9 +1,9 @@
 from .plot import (plot_surf_hemi, plot_surf_collage, 
                    plot_surf_vol_collage,
-                   plot)
+                   plot, plot_bars)
 from .ref import SurfRef, VolRef
 
 __all__ = ['plot_surf_hemi',
            'plot_surf_collage', 
            'plot_surf_vol_collage',
-           'plot', 'SurfRef', 'VolRef']
\ No newline at end of file
+           'plot', 'SurfRef', 'VolRef', 'plot_bars']
\ No newline at end of file
